# TreadI (Treading Issues)

<p align="center">
<img src="docs/images/treadi_logo.svg" alt="logo life ring resembling github issue icon" width="256"/>
</p>

Drowning in Github issues and pull requests?
TreadI helps you keep your head above water!

<img src="docs/images/issue_screen.png" alt="TreadI screen displaying issues and PRs" width="400"/>

TreadI displays the 5 most recently updated issues and PRs many repositories - even hundreds of repositories!

Filter issues and PRs with a subset of the familiar [Github search syntax](https://docs.github.com/en/search-github/searching-on-github/searching-issues-and-pull-requests).

Read [TreadI's documentation](https://sloretz.github.io/TreadI) to learn more.